@@ -1,11 +1,5 @@
+/* SPDX-License-Identifier: LGPL-2.1-only */
 /*
- * netlink/version.h	Versioning Information
- *
- *	This library is free software; you can redistribute it and/or
- *	modify it under the terms of the GNU Lesser General Public
- *	License as published by the Free Software Foundation version 2.1
- *	of the License.
- *
  * Copyright (c) 2008-2011 Thomas Graf <tgraf@suug.ch>
  */
 
@@ -14,18 +8,22 @@
 
 /* Compile Time Versioning Information */
 
-#define LIBNL_STRING "libnl 3.2.28"
-#define LIBNL_VERSION "3.2.28"
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+#define LIBNL_STRING "libnl 3.9.0"
+#define LIBNL_VERSION "3.9.0"
 
 #define LIBNL_VER_MAJ		3
-#define LIBNL_VER_MIN		2
-#define LIBNL_VER_MIC		28
+#define LIBNL_VER_MIN		9
+#define LIBNL_VER_MIC		0
 #define LIBNL_VER(maj,min)	((maj) << 8 | (min))
 #define LIBNL_VER_NUM		LIBNL_VER(LIBNL_VER_MAJ, LIBNL_VER_MIN)
 
-#define LIBNL_CURRENT		223
+#define LIBNL_CURRENT		226
 #define LIBNL_REVISION		0
-#define LIBNL_AGE		23
+#define LIBNL_AGE		26
 
 /* Run-time version information */
 
@@ -34,4 +32,8 @@ extern const int        nl_ver_maj;
 extern const int        nl_ver_min;
 extern const int        nl_ver_mic;
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
